class _ConstructorBuilder:
 """ Exposes the System.Reflection.Emit.ConstructorBuilder class to unmanaged code. """
 def GetIDsOfNames(self,riid,rgszNames,cNames,lcid,rgDispId):
  """
  GetIDsOfNames(self: _ConstructorBuilder,riid: Guid,rgszNames: IntPtr,cNames: UInt32,lcid: UInt32,rgDispId: IntPtr) -> Guid

  

   Maps a set of names to a corresponding set of dispatch identifiers.

  

   riid: Reserved for future use. Must be IID_NULL.

   rgszNames: An array of names to be mapped.

   cNames: The count of the names to be mapped.

   lcid: The locale context in which to interpret the names.

   rgDispId: An array allocated by the caller that receives the identifiers corresponding to the names.
  """
  pass
 def GetTypeInfo(self,iTInfo,lcid,ppTInfo):
  """
  GetTypeInfo(self: _ConstructorBuilder,iTInfo: UInt32,lcid: UInt32,ppTInfo: IntPtr)

   Retrieves the type information for an object,which can be used to get the type information for 

    an interface.

  

  

   iTInfo: The type information to return.

   lcid: The locale identifier for the type information.

   ppTInfo: A pointer to the requested type information object.
  """
  pass
 def GetTypeInfoCount(self,pcTInfo):
  """
  GetTypeInfoCount(self: _ConstructorBuilder) -> UInt32

  

   Retrieves the number of type information interfaces that an object provides (either 0 or 1).
  """
  pass
 def Invoke(self,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr):
  """
  Invoke(self: _ConstructorBuilder,dispIdMember: UInt32,riid: Guid,lcid: UInt32,wFlags: Int16,pDispParams: IntPtr,pVarResult: IntPtr,pExcepInfo: IntPtr,puArgErr: IntPtr) -> Guid

  

   Provides access to properties and methods exposed by an object.

  

   dispIdMember: An identifier of a member.

   riid: Reserved for future use. Must be IID_NULL.

   lcid: The locale context in which to interpret arguments.

   wFlags: Flags describing the context of the call.

   pDispParams: A pointer to a structure containing an array of arguments,an array of argument DISPIDs for 

    named arguments,and counts for the number of elements in the arrays.

  

   pVarResult: A pointer to the location where the result will be stored.

   pExcepInfo: A pointer to a structure that contains exception information.

   puArgErr: The index of the first argument that has an error.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



"""
The main rpw namespace and rpw.revit provide you with most of the imports will
need.

>>> from rpw import revit, db, ui
>>> db.Element(SomeElement)
>>> ui.Selection()
>>> revit.doc
>>> revit.uidoc.ActiveView


Revit Namespaces are also available:

>>> from rpw import DB, UI
>>> DB.ElementId(00000)
>>> UI.TaskDialog

In summary, if you use rpw, this could potentially be the only import line
you would need:

>>> from rpw import revit, db, ui, DB, UI

"""  #
import rpw
from rpw.utils.dotnet import clr, Process
from rpw.utils.logger import logger
from rpw.base import BaseObject


class Revit(BaseObject):
    """
    Revit Application Wrapper

    Note:
        The module path for the Revit Wrapper and its namespaces is ``rpw.__revit.Revit``.
        However, the ``Revit()`` is always instantiated on the initialization of rpw,
        and is stored along with the ``DB`` and ``UI`` namespaces in the
        root of rpw module.

        In other words, to use this wrapper all you need is to import
        ``from rpw import revit``

    >>> from rpw import revit
    >>> revit.doc
    <Autodesk.Revit.DB.Document>
    >>> revit.username
    gtalarico
    >>> revit.host
    'Dynamo'

    """

    class HOSTS():
        RPS = 'RPS'
        DYNAMO = 'Dynamo'

    def __init__(self):
        try:
            self.uiapp = __revit__
            self._host = Revit.HOSTS.RPS
        except NameError:
            try:
                # Try Getting handler from Dynamo RevitServices
                self.uiapp = self.find_dynamo_uiapp()
                self._host = Revit.HOSTS.DYNAMO
            except Exception as errmsg:
                logger.warning('Revit Application handle could not be found')

        try:
            # Add DB UI Import to globals so it can be imported by rpw
            clr.AddReference('RevitAPI')
            clr.AddReference('RevitAPIUI')
            from Autodesk.Revit import DB, UI
            globals().update({'DB': DB, 'UI': UI})
        except Exception:
            # Replace Globals with Mock Objects for Sphinx and ipy direct exec.
            logger.warning('RevitAPI References could not be added')
            from rpw.utils.sphinx_compat import MockObject
            globals().update({'DB': MockObject(fullname='Autodesk.Revit.DB'),
                              'UI': MockObject(fullname='Autodesk.Revit.DB')})
            self.uiapp = MockObject(fullname='Autodesk.Revit.UI.UIApplication')
            self._host = None

    def find_dynamo_uiapp(self):
        clr.AddReference("RevitServices")
        import RevitServices
        from RevitServices.Persistence import DocumentManager

        import sys
        sys.path.append(r'C:\Program Files (x86)\IronPython 2.7\Lib')
        return DocumentManager.Instance.CurrentUIApplication

    @property
    def host(self):
        """ Host is set based on how revit handle was found.

        Returns:
            Host (str): Revit Application Host ['RPS', 'Dynamo']
        """
        return self._host

    def open(self, path):
        """ Opens New Document """

    @property
    def doc(self):
        """ Returns: uiapp.ActiveUIDocument.Document """
        return getattr(self.uiapp.ActiveUIDocument, 'Document', None)

    @property
    def uidoc(self):
        """ Returns: uiapp.ActiveUIDocument """
        return getattr(self.uiapp, 'ActiveUIDocument', None)

    @property
    def active_view(self):
        """ Returns: uidoc.ActiveView """
        return rpw.db.Element(self.uidoc.ActiveView)

    @active_view.setter
    def active_view(self, view_reference):
        self.uidoc.ActiveView = view_reference

    @property
    def app(self):
        """ Returns: uidoc.Application """
        return self.uiapp.Application

    @property
    def docs(self):
        """ Returns: uidoc.Application.Documents """
        return [doc for doc in self.app.Documents]

    @property
    def username(self):
        """ Returns: uidoc.Application.Username """
        return self.uiapp.Application.Username

    @property
    def version(self):
        """ Returns: uidoc.Application.Username """
        return RevitVersion(self.uiapp)

    @property
    def process(self):
        """ Returns: Process.GetCurrentProcess() """
        return Process.GetCurrentProcess()

    @property
    def process_id(self):
        """ Returns: Process.GetCurrentProcess() """
        return self.process.Id

    @property
    def process_name(self):
        """ Returns: Process.GetCurrentProcess() """
        return self.process.ProcessName

    def __repr__(self):
        return '<{version} [{process}:{pid}]>'.format(version=self.version,
                                                      process=self.process_name,
                                                      pid=self.process_id)
    # Check what this is
    # @property
    # def process(self):
    #     clr.AddReferenceByPartialName('System.Windows.Forms')
    #     # noinspection PyUnresolvedReferences
    #     from System.Windows.Forms import Screen
    #     return Screen.FromHandle(Process.GetCurrentProcess().MainWindowHandle)


class RevitVersion():
    def __init__(self, uiapp):
        self.uiapp = uiapp

    @property
    def year(self):
        return self.uiapp.Application.VersionNumber

    @property
    def name(self):
        return self.uiapp.Application.VersionName

    @property
    def build(self):
        return self.uiapp.Application.VersionBuild

    def __lt__(self, other):
        """ Handle Version Comparison Logic"""
        raise NotImplemented

    def __gt__(self, other):
        """ Handle Version Comparison Logic"""
        raise NotImplemented

    def __repr__(self):
        return '<Version: {year}: {build}>'.format(year=self.name,
                                                   build=self.build)

    def __str__(self):
        return '{name}:{build}'.format(name=self.name, build=self.build)


revit = Revit()



class PopupEventArgs(CancelEventArgs):
 """
 Provides data for the System.Windows.Forms.ToolTip.Popup event.

 

 PopupEventArgs(associatedWindow: IWin32Window,associatedControl: Control,isBalloon: bool,size: Size)
 """
 @staticmethod
 def __new__(self,associatedWindow,associatedControl,isBalloon,size):
  """ __new__(cls: type,associatedWindow: IWin32Window,associatedControl: Control,isBalloon: bool,size: Size) """
  pass
 AssociatedControl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the control for which the System.Windows.Forms.ToolTip is being drawn.



Get: AssociatedControl(self: PopupEventArgs) -> Control



"""

 AssociatedWindow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the window to which this System.Windows.Forms.ToolTip is bound.



Get: AssociatedWindow(self: PopupEventArgs) -> IWin32Window



"""

 IsBalloon=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the ToolTip is displayed as a standard rectangular or a balloon window.



Get: IsBalloon(self: PopupEventArgs) -> bool



"""

 ToolTipSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the size of the ToolTip.



Get: ToolTipSize(self: PopupEventArgs) -> Size



Set: ToolTipSize(self: PopupEventArgs)=value

"""





class CommonObjectSecurity(ObjectSecurity):
 """ Controls access to objects without direct manipulation of access control lists (ACLs). This class is the abstract base class for the System.Security.AccessControl.NativeObjectSecurity class. """
 def AddAccessRule(self,*args):
  """
  AddAccessRule(self: CommonObjectSecurity,rule: AccessRule)

   Adds the specified access rule to the Discretionary Access Control List (DACL) associated with 

    this System.Security.AccessControl.CommonObjectSecurity object.

  

  

   rule: The access rule to add.
  """
  pass
 def AddAuditRule(self,*args):
  """
  AddAuditRule(self: CommonObjectSecurity,rule: AuditRule)

   Adds the specified audit rule to the System Access Control List (SACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object.

  

  

   rule: The audit rule to add.
  """
  pass
 def GetAccessRules(self,includeExplicit,includeInherited,targetType):
  """
  GetAccessRules(self: CommonObjectSecurity,includeExplicit: bool,includeInherited: bool,targetType: Type) -> AuthorizationRuleCollection

  

   Gets a collection of the access rules associated with the specified security identifier.

  

   includeExplicit: true to include access rules explicitly set for the object.

   includeInherited: true to include inherited access rules.

   targetType: Specifies whether the security identifier for which to retrieve access rules is of type 

    T:System.Security.Principal.SecurityIdentifier or type T:System.Security.Principal.NTAccount. 

    The value of this parameter must be a type that can be translated to  the 

    System.Security.Principal.SecurityIdentifier type.

  

   Returns: The collection of access rules associated with the specified 

    System.Security.Principal.SecurityIdentifier object.
  """
  pass
 def GetAuditRules(self,includeExplicit,includeInherited,targetType):
  """
  GetAuditRules(self: CommonObjectSecurity,includeExplicit: bool,includeInherited: bool,targetType: Type) -> AuthorizationRuleCollection

  

   Gets a collection of the audit rules associated with the specified security identifier.

  

   includeExplicit: true to include audit rules explicitly set for the object.

   includeInherited: true to include inherited audit rules.

   targetType: The security identifier for which to retrieve audit rules. This must be an object that can be 

    cast as a System.Security.Principal.SecurityIdentifier object.

  

   Returns: The collection of audit rules associated with the specified 

    System.Security.Principal.SecurityIdentifier object.
  """
  pass
 def RemoveAccessRule(self,*args):
  """
  RemoveAccessRule(self: CommonObjectSecurity,rule: AccessRule) -> bool

  

   Removes access rules that contain the same security identifier and access mask as the specified 

    access rule from the Discretionary Access Control List (DACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object.

  

  

   rule: The access rule to remove.

   Returns: true if the access rule was successfully removed; otherwise,false.
  """
  pass
 def RemoveAccessRuleAll(self,*args):
  """
  RemoveAccessRuleAll(self: CommonObjectSecurity,rule: AccessRule)

   Removes all access rules that have the same security identifier as the specified access rule 

    from the Discretionary Access Control List (DACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object.

  

  

   rule: The access rule to remove.
  """
  pass
 def RemoveAccessRuleSpecific(self,*args):
  """
  RemoveAccessRuleSpecific(self: CommonObjectSecurity,rule: AccessRule)

   Removes all access rules that exactly match the specified access rule from the Discretionary 

    Access Control List (DACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object.

  

  

   rule: The access rule to remove.
  """
  pass
 def RemoveAuditRule(self,*args):
  """
  RemoveAuditRule(self: CommonObjectSecurity,rule: AuditRule) -> bool

  

   Removes audit rules that contain the same security identifier and access mask as the specified 

    audit rule from the System Access Control List (SACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object.

  

  

   rule: The audit rule to remove.

   Returns: true if the audit rule was successfully removed; otherwise,false.
  """
  pass
 def RemoveAuditRuleAll(self,*args):
  """
  RemoveAuditRuleAll(self: CommonObjectSecurity,rule: AuditRule)

   Removes all audit rules that have the same security identifier as the specified audit rule from 

    the System Access Control List (SACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object.

  

  

   rule: The audit rule to remove.
  """
  pass
 def RemoveAuditRuleSpecific(self,*args):
  """
  RemoveAuditRuleSpecific(self: CommonObjectSecurity,rule: AuditRule)

   Removes all audit rules that exactly match the specified audit rule from the System Access 

    Control List (SACL) associated with this System.Security.AccessControl.CommonObjectSecurity 

    object.

  

  

   rule: The audit rule to remove.
  """
  pass
 def ResetAccessRule(self,*args):
  """
  ResetAccessRule(self: CommonObjectSecurity,rule: AccessRule)

   Removes all access rules in the Discretionary Access Control List (DACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object and then adds the specified access 

    rule.

  

  

   rule: The access rule to reset.
  """
  pass
 def SetAccessRule(self,*args):
  """
  SetAccessRule(self: CommonObjectSecurity,rule: AccessRule)

   Removes all access rules that contain the same security identifier and qualifier as the 

    specified access rule in the Discretionary Access Control List (DACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object and then adds the specified access 

    rule.

  

  

   rule: The access rule to set.
  """
  pass
 def SetAuditRule(self,*args):
  """
  SetAuditRule(self: CommonObjectSecurity,rule: AuditRule)

   Removes all audit rules that contain the same security identifier and qualifier as the specified 

    audit rule in the System Access Control List (SACL) associated with this 

    System.Security.AccessControl.CommonObjectSecurity object and then adds the specified audit 

    rule.

  

  

   rule: The audit rule to set.
  """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """ __new__(cls: type,isContainer: bool) """
  pass
 AccessRulesModified=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that specifies whether the access rules associated with this System.Security.AccessControl.ObjectSecurity object have been modified.



"""

 AuditRulesModified=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that specifies whether the audit rules associated with this System.Security.AccessControl.ObjectSecurity object have been modified.



"""

 GroupModified=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that specifies whether the group associated with the securable object has been modified.



"""

 IsContainer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether this System.Security.AccessControl.ObjectSecurity object is a container object.



"""

 IsDS=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether this System.Security.AccessControl.ObjectSecurity object is a directory object.



"""

 OwnerModified=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that specifies whether the owner of the securable object has been modified.



"""





class DESCKIND(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.DESCKIND instead.

 

 enum DESCKIND,values: DESCKIND_FUNCDESC (1),DESCKIND_IMPLICITAPPOBJ (4),DESCKIND_MAX (5),DESCKIND_NONE (0),DESCKIND_TYPECOMP (3),DESCKIND_VARDESC (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DESCKIND_FUNCDESC=None
 DESCKIND_IMPLICITAPPOBJ=None
 DESCKIND_MAX=None
 DESCKIND_NONE=None
 DESCKIND_TYPECOMP=None
 DESCKIND_VARDESC=None
 value__=None




class PageRange(object):
 """
 Specifies a range of pages.

 

 PageRange(page: int)

 PageRange(pageFrom: int,pageTo: int)
 """
 def Equals(self,*__args):
  """
  Equals(self: PageRange,pageRange: PageRange) -> bool

  

   Tests whether a System.Windows.Controls.PageRange is equal to this 

    System.Windows.Controls.PageRange.

  

  

   pageRange: The System.Windows.Controls.PageRange tested.

   Returns: true if the two System.Windows.Controls.PageRange objects are equal; otherwise,false.

  Equals(self: PageRange,obj: object) -> bool

  

   Tests whether an object of unknown type is equal to this System.Windows.Controls.PageRange.

  

   obj: The object tested.

   Returns: true if the object is of type System.Windows.Controls.PageRange and is equal to this 

    System.Windows.Controls.PageRange; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: PageRange) -> int

  

   Gets the hash code value for the System.Windows.Controls.PageRange.

   Returns: The hash code value for the System.Windows.Controls.PageRange.
  """
  pass
 def ToString(self):
  """
  ToString(self: PageRange) -> str

  

   Gets a string representation of the range.

   Returns: A string that represents the range of pages in the format 

    "System.Windows.Controls.PageRange.PageFrom-System.Windows.Controls.PageRange.PageTo".
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,page: int)

  __new__(cls: type,pageFrom: int,pageTo: int)

  __new__[PageRange]() -> PageRange
  """
  pass
 def __ne__(self,*args):
  pass
 PageFrom=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the page number of the first page in the range.



Get: PageFrom(self: PageRange) -> int



Set: PageFrom(self: PageRange)=value

"""

 PageTo=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the page number of the last page in the range.



Get: PageTo(self: PageRange) -> int



Set: PageTo(self: PageRange)=value

"""





# encoding: utf-8
# module System.Media calls itself Media
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class SoundPlayer(Component,IComponent,IDisposable,ISerializable):
 """
 Controls playback of a sound from a .wav file.

 

 SoundPlayer()

 SoundPlayer(soundLocation: str)

 SoundPlayer(stream: Stream)
 """
 def Dispose(self):
  """
  Dispose(self: Component,disposing: bool)

   Releases the unmanaged resources used by the System.ComponentModel.Component and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def Load(self):
  """
  Load(self: SoundPlayer)

   Loads a sound synchronously.
  """
  pass
 def LoadAsync(self):
  """
  LoadAsync(self: SoundPlayer)

   Loads a .wav file from a stream or a Web resource using a new thread.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnLoadCompleted(self,*args):
  """
  OnLoadCompleted(self: SoundPlayer,e: AsyncCompletedEventArgs)

   Raises the System.Media.SoundPlayer.LoadCompleted event.

  

   e: An System.ComponentModel.AsyncCompletedEventArgs  that contains the event data.
  """
  pass
 def OnSoundLocationChanged(self,*args):
  """
  OnSoundLocationChanged(self: SoundPlayer,e: EventArgs)

   Raises the System.Media.SoundPlayer.SoundLocationChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnStreamChanged(self,*args):
  """
  OnStreamChanged(self: SoundPlayer,e: EventArgs)

   Raises the System.Media.SoundPlayer.StreamChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def Play(self):
  """
  Play(self: SoundPlayer)

   Plays the .wav file using a new thread,and loads the .wav file first if it has not been loaded.
  """
  pass
 def PlayLooping(self):
  """
  PlayLooping(self: SoundPlayer)

   Plays and loops the .wav file using a new thread,and loads the .wav file first if it has not 

    been loaded.
  """
  pass
 def PlaySync(self):
  """
  PlaySync(self: SoundPlayer)

   Plays the .wav file and loads the .wav file first if it has not been loaded.
  """
  pass
 def Stop(self):
  """
  Stop(self: SoundPlayer)

   Stops playback of the sound if playback is occurring.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,soundLocation: str)

  __new__(cls: type,stream: Stream)

  __new__(cls: type,serializationInfo: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 IsLoadCompleted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether loading of a .wav file has successfully completed.



Get: IsLoadCompleted(self: SoundPlayer) -> bool



"""

 LoadTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the time,in milliseconds,in which the .wav file must load.



Get: LoadTimeout(self: SoundPlayer) -> int



Set: LoadTimeout(self: SoundPlayer)=value

"""

 SoundLocation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the file path or URL of the .wav file to load.



Get: SoundLocation(self: SoundPlayer) -> str



Set: SoundLocation(self: SoundPlayer)=value

"""

 Stream=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.IO.Stream from which to load the .wav file.



Get: Stream(self: SoundPlayer) -> Stream



Set: Stream(self: SoundPlayer)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Object that contains data about the System.Media.SoundPlayer.



Get: Tag(self: SoundPlayer) -> object



Set: Tag(self: SoundPlayer)=value

"""


 LoadCompleted=None
 SoundLocationChanged=None
 StreamChanged=None


class SystemSound(object):
 """ Represents a system sound type. """
 def Play(self):
  """
  Play(self: SystemSound)

   Plays the system sound type.
  """
  pass

class SystemSounds(object):
 """ Retrieves sounds associated with a set of Windows operating system sound-event types. This class cannot be inherited. """
 Asterisk=None
 Beep=None
 Exclamation=None
 Hand=None
 Question=None





class GridItem(object):
 """ Implements one row in a System.Windows.Forms.PropertyGrid. """
 def Select(self):
  """
  Select(self: GridItem) -> bool

  

   When overridden in a derived class,selects this System.Windows.Forms.GridItem in the 

    System.Windows.Forms.PropertyGrid.

  

   Returns: true if the selection is successful; otherwise,false.
  """
  pass
 Expandable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets a value indicating whether the specified property is expandable to show nested properties.



Get: Expandable(self: GridItem) -> bool



"""

 Expanded=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets or sets a value indicating whether the System.Windows.Forms.GridItem is in an expanded state.



Get: Expanded(self: GridItem) -> bool



Set: Expanded(self: GridItem)=value

"""

 GridItems=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets the collection of System.Windows.Forms.GridItem objects,if any,associated as a child of this System.Windows.Forms.GridItem.



Get: GridItems(self: GridItem) -> GridItemCollection



"""

 GridItemType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets the type of this System.Windows.Forms.GridItem.



Get: GridItemType(self: GridItem) -> GridItemType



"""

 Label=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets the text of this System.Windows.Forms.GridItem.



Get: Label(self: GridItem) -> str



"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets the parent System.Windows.Forms.GridItem of this System.Windows.Forms.GridItem,if any.



Get: Parent(self: GridItem) -> GridItem



"""

 PropertyDescriptor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets the System.ComponentModel.PropertyDescriptor that is associated with this System.Windows.Forms.GridItem.



Get: PropertyDescriptor(self: GridItem) -> PropertyDescriptor



"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets user-defined data about the System.Windows.Forms.GridItem.



Get: Tag(self: GridItem) -> object



Set: Tag(self: GridItem)=value

"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets the current value of this System.Windows.Forms.GridItem.



Get: Value(self: GridItem) -> object



"""





"""
Spatial Element Wrappers

"""  #

import rpw
from rpw import revit, DB
from rpw.db import Element
from rpw.utils.logger import logger
from rpw.db.builtins import BipEnum


class Room(Element):
    """
    `DB.Architecture.Room` Wrapper
    Inherits from :any:`Element`

    >>> from rpw import db
    >>> room = db.Room(SomeRoom)
    <rpw:Room % DB.Architecture.Room | name:Office number:122>
    >>> room.name
    'Office'
    >>> room.number
    '122'
    >>> room.is_placed
    True
    >>> room.is_bounded
    True

    Attribute:
        _revit_object (DB.Architecture.Room): Wrapped ``DB.Architecture.Room``
    """

    _revit_object_class = DB.Architecture.Room
    _revit_object_category = DB.BuiltInCategory.OST_Rooms
    _collector_params = {'of_category': _revit_object_category,
                         'is_not_type': True}

    @property
    def name(self):
        """ Room Name as parameter Value: ``ROOM_NAME`` built-in parameter"""
        # Note: For an unknown reason, roominstance.Name does not work on IPY
        return self.parameters.builtins['ROOM_NAME'].value

    @name.setter
    def name(self, value):
        self.parameters.builtins['ROOM_NAME'].value = value

    @property
    def number(self):
        """ Room Number as parameter Value: ``ROOM_NUMBER`` built-in parameter"""
        return self.parameters.builtins['ROOM_NUMBER'].value

    @number.setter
    def number(self, value):
        self.parameters.builtins['ROOM_NUMBER'].value = value

    # @property
    # def from_room(self, value):
        # TODO: from_room

    @property
    def is_placed(self):
        """ ``bool`` for whether Room is Placed.
        Uses result of ``Room.Location`` attribute to define if room is Placed.
        """
        return bool(self._revit_object.Location)

    @property
    def is_bounded(self):
        """ ``bool`` for whether Room is Bounded.
        Uses result of ``Room.Area`` attribute to define if room is Bounded.
        """
        return self._revit_object.Area > 0

    def __repr__(self):
        return super(Room, self).__repr__(data={'name': self.name,
                                                'number': self.number})


class Area(Room):
    """
    `DB.Area` Wrapper
    Inherits from :any:`Room`

    >>> from rpw import db
    >>> area = db.Area(SomeArea)
    <rpw:Area % DB.Area | name:USF area: 100.0>
    >>> area.name
    'Rentable'
    >>> area.is_placed
    True
    >>> area.is_bounded
    True

    Attribute:
        _revit_object (DB.Area): Wrapped ``DB.Area``
    """

    _revit_object_class = DB.Area
    _revit_object_category = DB.BuiltInCategory.OST_Areas
    _collector_params = {'of_category': _revit_object_category,
                         'is_not_type': True}

    @property
    def name(self):
        """ Area Scheme Name: Area attribute parameter"""
        return self.scheme.name

    @property
    def scheme(self):
        """ Area Scheme: Wrapped Area Scheme"""
        return AreaScheme(self._revit_object.AreaScheme)

    @property
    def area(self):
        """ Area: .Area attribute"""
        return self._revit_object.Area

    def __repr__(self):
        return super(Element, self).__repr__(data={'name': self.name,
                                                   'area': self.area})


class AreaScheme(Element):
    """
    `DB.AreaScheme` Wrapper
    Inherits from :any:`Element`

    >>> scheme = wrapped_area.scheme
    <rwp:AreaScheme % DB.AreaScheme | name:USF>
    >>> scheme.areas
    [ < Autodesk.Revit.DB.Area>, ...]
    >>> scheme.name
    'USF'

    Attribute:
        _revit_object (DB.AreaScheme): Wrapped ``DB.AreaScheme``
    """

    _revit_object_class = DB.AreaScheme
    _collector_params = {'of_class': _revit_object_class}

    @property
    def name(self):
        """ Area Scheme Name: Area attribute parameter"""
        return self._revit_object.Name

    @property
    def areas(self):
        """ Returns all Area Instances of this Area Scheme """
        bip = BipEnum.get_id('AREA_SCHEME_ID')
        param_filter = rpw.db.Collector.ParameterFilter(bip, equals=self._revit_object.Id)
        collector = rpw.db.Collector(parameter_filter=param_filter,
                                     **Area._collector_params)
        return collector.wrapped_elements

    def __repr__(self):
        return super(AreaScheme, self).__repr__(data={'name': self.name})



class VirtualizationCacheLengthConverter(TypeConverter):
 """ VirtualizationCacheLengthConverter() """
 def CanConvertFrom(self,*__args):
  """ CanConvertFrom(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,sourceType: Type) -> bool """
  pass
 def CanConvertTo(self,*__args):
  """ CanConvertTo(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,destinationType: Type) -> bool """
  pass
 def ConvertFrom(self,*__args):
  """ ConvertFrom(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,cultureInfo: CultureInfo,source: object) -> object """
  pass
 def ConvertTo(self,*__args):
  """ ConvertTo(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,cultureInfo: CultureInfo,value: object,destinationType: Type) -> object """
  pass



class ProcessStartInfo(object):
 """
 Specifies a set of values that are used when you start a process.

 

 ProcessStartInfo()

 ProcessStartInfo(fileName: str)

 ProcessStartInfo(fileName: str,arguments: str)
 """
 @staticmethod
 def __new__(self,fileName=None,arguments=None):
  """
  __new__(cls: type)

  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,arguments: str)
  """
  pass
 Arguments=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the set of command-line arguments to use when starting the application.



Get: Arguments(self: ProcessStartInfo) -> str



Set: Arguments(self: ProcessStartInfo)=value

"""

 CreateNoWindow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether to start the process in a new window.



Get: CreateNoWindow(self: ProcessStartInfo) -> bool



Set: CreateNoWindow(self: ProcessStartInfo)=value

"""

 Domain=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that identifies the domain to use when starting the process.



Get: Domain(self: ProcessStartInfo) -> str



Set: Domain(self: ProcessStartInfo)=value

"""

 Environment=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Environment(self: ProcessStartInfo) -> IDictionary[str,str]



"""

 EnvironmentVariables=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets search paths for files,directories for temporary files,application-specific options,and other similar information.



Get: EnvironmentVariables(self: ProcessStartInfo) -> StringDictionary



"""

 ErrorDialog=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether an error dialog box is displayed to the user if the process cannot be started.



Get: ErrorDialog(self: ProcessStartInfo) -> bool



Set: ErrorDialog(self: ProcessStartInfo)=value

"""

 ErrorDialogParentHandle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the window handle to use when an error dialog box is shown for a process that cannot be started.



Get: ErrorDialogParentHandle(self: ProcessStartInfo) -> IntPtr



Set: ErrorDialogParentHandle(self: ProcessStartInfo)=value

"""

 FileName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the application or document to start.



Get: FileName(self: ProcessStartInfo) -> str



Set: FileName(self: ProcessStartInfo)=value

"""

 LoadUserProfile=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the Windows user profile is to be loaded from the registry.



Get: LoadUserProfile(self: ProcessStartInfo) -> bool



Set: LoadUserProfile(self: ProcessStartInfo)=value

"""

 Password=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a secure string that contains the user password to use when starting the process.



Get: Password(self: ProcessStartInfo) -> SecureString



Set: Password(self: ProcessStartInfo)=value

"""

 PasswordInClearText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PasswordInClearText(self: ProcessStartInfo) -> str



Set: PasswordInClearText(self: ProcessStartInfo)=value

"""

 RedirectStandardError=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the error output of an application is written to the System.Diagnostics.Process.StandardError stream.



Get: RedirectStandardError(self: ProcessStartInfo) -> bool



Set: RedirectStandardError(self: ProcessStartInfo)=value

"""

 RedirectStandardInput=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the input for an application is read from the System.Diagnostics.Process.StandardInput stream.



Get: RedirectStandardInput(self: ProcessStartInfo) -> bool



Set: RedirectStandardInput(self: ProcessStartInfo)=value

"""

 RedirectStandardOutput=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the output of an application is written to the System.Diagnostics.Process.StandardOutput stream.



Get: RedirectStandardOutput(self: ProcessStartInfo) -> bool



Set: RedirectStandardOutput(self: ProcessStartInfo)=value

"""

 StandardErrorEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the preferred encoding for error output.



Get: StandardErrorEncoding(self: ProcessStartInfo) -> Encoding



Set: StandardErrorEncoding(self: ProcessStartInfo)=value

"""

 StandardOutputEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the preferred encoding for standard output.



Get: StandardOutputEncoding(self: ProcessStartInfo) -> Encoding



Set: StandardOutputEncoding(self: ProcessStartInfo)=value

"""

 UserName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the user name to be used when starting the process.



Get: UserName(self: ProcessStartInfo) -> str



Set: UserName(self: ProcessStartInfo)=value

"""

 UseShellExecute=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether to use the operating system shell to start the process.



Get: UseShellExecute(self: ProcessStartInfo) -> bool



Set: UseShellExecute(self: ProcessStartInfo)=value

"""

 Verb=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the verb to use when opening the application or document specified by the System.Diagnostics.ProcessStartInfo.FileName property.



Get: Verb(self: ProcessStartInfo) -> str



Set: Verb(self: ProcessStartInfo)=value

"""

 Verbs=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the set of verbs associated with the type of file specified by the System.Diagnostics.ProcessStartInfo.FileName property.



Get: Verbs(self: ProcessStartInfo) -> Array[str]



"""

 WindowStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the window state to use when the process is started.



Get: WindowStyle(self: ProcessStartInfo) -> ProcessWindowStyle



Set: WindowStyle(self: ProcessStartInfo)=value

"""

 WorkingDirectory=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the initial directory for the process to be started.



Get: WorkingDirectory(self: ProcessStartInfo) -> str



Set: WorkingDirectory(self: ProcessStartInfo)=value

"""





# encoding: utf-8
# module System.Windows.Markup.Localizer calls itself Localizer
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class BamlLocalizabilityResolver(object):
 """ Resolves localizable settings for classes and properties in binary XAML (BAML). """
 def GetElementLocalizability(self,assembly,className):
  """
  GetElementLocalizability(self: BamlLocalizabilityResolver,assembly: str,className: str) -> ElementLocalizability

  

   Returns a value that indicates whether a specified type of element can be localized and,if so,

    whether it can be formatted inline.

  

  

   assembly: The full name of the assembly that contains BAML to be localized.

   className: The full class name of the element that you want to retrieve localizability information for.

   Returns: An object that contains the localizability information for the specified assembly and element.
  """
  pass
 def GetPropertyLocalizability(self,assembly,className,property):
  """
  GetPropertyLocalizability(self: BamlLocalizabilityResolver,assembly: str,className: str,property: str) -> LocalizabilityAttribute

  

   Returns a value that indicates whether a specified property of a specified type of element can 

    be localized.

  

  

   assembly: The full name of the assembly that contains BAML to be localized.

   className: The full class name of the element that you want to retrieve localizability information for.

   property: The name of the property that you want to retrieve localizability information for.

   Returns: An object that specifies whether and how the property can be localized.
  """
  pass
 def ResolveAssemblyFromClass(self,className):
  """
  ResolveAssemblyFromClass(self: BamlLocalizabilityResolver,className: str) -> str

  

   Returns the full name of the assembly that contains the specified class.

  

   className: The full class name.

   Returns: The full name of the assembly that contains the class.
  """
  pass
 def ResolveFormattingTagToClass(self,formattingTag):
  """
  ResolveFormattingTagToClass(self: BamlLocalizabilityResolver,formattingTag: str) -> str

  

   Returns the full class name of a XAML tag that has not been encountered in BAML.

  

   formattingTag: The name of the tag.

   Returns: The full class name associated with the tag.
  """
  pass

class BamlLocalizableResource(object):
 """
 Represents a localizable resource in a BAML stream.

 

 BamlLocalizableResource()

 BamlLocalizableResource(content: str,comments: str,category: LocalizationCategory,modifiable: bool,readable: bool)
 """
 def Equals(self,other):
  """
  Equals(self: BamlLocalizableResource,other: object) -> bool

  

   Determines whether a specified System.Windows.Markup.Localizer.BamlLocalizableResource object is 

    equal to this object.

  

  

   other: The System.Windows.Markup.Localizer.BamlLocalizableResource object test for equality.

   Returns: true if other is equal to this object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: BamlLocalizableResource) -> int

  

   Returns an integer hash code representing this instance.

   Returns: An integer hash code.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,content=None,comments=None,category=None,modifiable=None,readable=None):
  """
  __new__(cls: type)

  __new__(cls: type,content: str,comments: str,category: LocalizationCategory,modifiable: bool,readable: bool)
  """
  pass
 def __ne__(self,*args):
  pass
 Category=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the localization category of a resource.



Get: Category(self: BamlLocalizableResource) -> LocalizationCategory



Set: Category(self: BamlLocalizableResource)=value

"""

 Comments=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the localization comments associated with a resource.



Get: Comments(self: BamlLocalizableResource) -> str



Set: Comments(self: BamlLocalizableResource)=value

"""

 Content=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the localizable content.



Get: Content(self: BamlLocalizableResource) -> str



Set: Content(self: BamlLocalizableResource)=value

"""

 Modifiable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the localizable resource is modifiable.



Get: Modifiable(self: BamlLocalizableResource) -> bool



Set: Modifiable(self: BamlLocalizableResource)=value

"""

 Readable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the resource is visible for translation.



Get: Readable(self: BamlLocalizableResource) -> bool



Set: Readable(self: BamlLocalizableResource)=value

"""



class BamlLocalizableResourceKey(object):
 """
 Represents a key that is used to identify localizable resources in a System.Windows.Markup.Localizer.BamlLocalizationDictionary.

 

 BamlLocalizableResourceKey(uid: str,className: str,propertyName: str)
 """
 def Equals(self,other):
  """
  Equals(self: BamlLocalizableResourceKey,other: object) -> bool

  

   Compares an object to an instance of System.Windows.Markup.Localizer.BamlLocalizableResourceKey 

    for equality.

  

  

   other: The object to compare for equality.

   Returns: true if the two instances are equal; otherwise,false.

  Equals(self: BamlLocalizableResourceKey,other: BamlLocalizableResourceKey) -> bool

  

   Compares two instances of System.Windows.Markup.Localizer.BamlLocalizableResourceKey for 

    equality.

  

  

   other: The other instance of System.Windows.Markup.Localizer.BamlLocalizableResourceKey to compare for 

    equality.

  

   Returns: true if the two instances are equal; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: BamlLocalizableResourceKey) -> int

  

   Returns an integer hash code representing this instance.

   Returns: An integer hash code.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,uid,className,propertyName):
  """ __new__(cls: type,uid: str,className: str,propertyName: str) """
  pass
 def __ne__(self,*args):
  pass
 AssemblyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the assembly that defines the type of the localizable resource as declared by its System.Windows.Markup.Localizer.BamlLocalizableResourceKey.ClassName.



Get: AssemblyName(self: BamlLocalizableResourceKey) -> str



"""

 ClassName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the class name component of this System.Windows.Markup.Localizer.BamlLocalizableResourceKey.



Get: ClassName(self: BamlLocalizableResourceKey) -> str



"""

 PropertyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the property name component of this System.Windows.Markup.Localizer.BamlLocalizableResourceKey.



Get: PropertyName(self: BamlLocalizableResourceKey) -> str



"""

 Uid=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Uid component of this System.Windows.Markup.Localizer.BamlLocalizableResourceKey.



Get: Uid(self: BamlLocalizableResourceKey) -> str



"""



class BamlLocalizationDictionary(object,IDictionary,ICollection,IEnumerable):
 """
 Contains all the localizable resources in a BAML record.

 

 BamlLocalizationDictionary()
 """
 def Add(self,key,value):
  """
  Add(self: BamlLocalizationDictionary,key: BamlLocalizableResourceKey,value: BamlLocalizableResource)

   Adds an item with the provided key and value to the 

    System.Windows.Markup.Localizer.BamlLocalizationDictionary.

  

  

   key: A key for the resource.

   value: An object that contains the resource.
  """
  pass
 def Clear(self):
  """
  Clear(self: BamlLocalizationDictionary)

   Deletes all resources from the System.Windows.Markup.Localizer.BamlLocalizationDictionary object.
  """
  pass
 def Contains(self,key):
  """
  Contains(self: BamlLocalizationDictionary,key: BamlLocalizableResourceKey) -> bool

  

   Determines whether a System.Windows.Markup.Localizer.BamlLocalizationDictionary object contains 

    a resource with a specified key.

  

  

   key: The resource key to find.

   Returns: true if the System.Windows.Markup.Localizer.BamlLocalizationDictionary object contains a 

    resource with the specified key; otherwise,false.
  """
  pass
 def CopyTo(self,array,arrayIndex):
  """
  CopyTo(self: BamlLocalizationDictionary,array: Array[DictionaryEntry],arrayIndex: int)

   Copies the contents of a System.Windows.Markup.Localizer.BamlLocalizationDictionary object to a 

    one-dimensional array of System.Collections.DictionaryEntry objects,starting at a specified 

    index.

  

  

   array: An array of objects to hold the data.

   arrayIndex: The starting index value.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: BamlLocalizationDictionary) -> BamlLocalizationDictionaryEnumerator

  

   Returns an enumerator that iterates through the 

    System.Windows.Markup.Localizer.BamlLocalizationDictionary.

  

   Returns: A specialized System.Windows.Markup.Localizer.BamlLocalizationDictionaryEnumerator that can 

    iterate the contents of the dictionary.
  """
  pass
 def Remove(self,key):
  """
  Remove(self: BamlLocalizationDictionary,key: BamlLocalizableResourceKey)

   Removes a specified localizable resource from the 

    System.Windows.Markup.Localizer.BamlLocalizationDictionary.

  

  

   key: The key for the resource to be removed.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IDictionary,key: object) -> bool

  

   Determines whether the System.Collections.IDictionary object contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.IDictionary object.

   Returns: true if the System.Collections.IDictionary contains an element with the key; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of localizable resources in the System.Windows.Markup.Localizer.BamlLocalizationDictionary.



Get: Count(self: BamlLocalizationDictionary) -> int



"""

 IsFixedSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.Windows.Markup.Localizer.BamlLocalizationDictionary object has a fixed size.



Get: IsFixedSize(self: BamlLocalizationDictionary) -> bool



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.Windows.Markup.Localizer.BamlLocalizationDictionary object is read-only.



Get: IsReadOnly(self: BamlLocalizationDictionary) -> bool



"""

 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection that contains all the keys in the System.Windows.Markup.Localizer.BamlLocalizationDictionary object.



Get: Keys(self: BamlLocalizationDictionary) -> ICollection



"""

 RootElementKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the key of the root element,if it is localizable.



Get: RootElementKey(self: BamlLocalizationDictionary) -> BamlLocalizableResourceKey



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection that contains all the values in the System.Windows.Markup.Localizer.BamlLocalizationDictionary.



Get: Values(self: BamlLocalizationDictionary) -> ICollection



"""



class BamlLocalizationDictionaryEnumerator(object,IDictionaryEnumerator,IEnumerator):
 """ Defines a specialized enumerator that can enumerate over the content of a System.Windows.Markup.Localizer.BamlLocalizationDictionary object. """
 def MoveNext(self):
  """
  MoveNext(self: BamlLocalizationDictionaryEnumerator) -> bool

  

   Moves to the next item in the collection.

   Returns: true if the enumerator successfully advances to the next element. If there are no remaining 

    elements,this method returns false.
  """
  pass
 def next(self,*args):
  """ next(self: object) -> object """
  pass
 def Reset(self):
  """
  Reset(self: BamlLocalizationDictionaryEnumerator)

   Returns the enumerator to its initial position,which is before the first object in the 

    collection.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerator) -> object """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Current=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current object in the collection.



Get: Current(self: BamlLocalizationDictionaryEnumerator) -> DictionaryEntry



"""

 Entry=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current position's System.Collections.DictionaryEntry object.



Get: Entry(self: BamlLocalizationDictionaryEnumerator) -> DictionaryEntry



"""

 Key=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the key of the current entry.



Get: Key(self: BamlLocalizationDictionaryEnumerator) -> BamlLocalizableResourceKey



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the current entry.



Get: Value(self: BamlLocalizationDictionaryEnumerator) -> BamlLocalizableResource



"""



class BamlLocalizer(object):
 """
 Extracts resources from a BAML file and generates a localized version of a BAML source.

 

 BamlLocalizer(source: Stream)

 BamlLocalizer(source: Stream,resolver: BamlLocalizabilityResolver)

 BamlLocalizer(source: Stream,resolver: BamlLocalizabilityResolver,comments: TextReader)
 """
 def ExtractResources(self):
  """
  ExtractResources(self: BamlLocalizer) -> BamlLocalizationDictionary

  

   Extracts all localizable resources from a BAML stream.

   Returns: A copy of the localizable resources from a BAML stream,in the form of a 

    System.Windows.Markup.Localizer.BamlLocalizationDictionary.
  """
  pass
 def OnErrorNotify(self,*args):
  """
  OnErrorNotify(self: BamlLocalizer,e: BamlLocalizerErrorNotifyEventArgs)

   Raises the System.Windows.Markup.Localizer.BamlLocalizer.ErrorNotify event.

  

   e: Required event arguments.
  """
  pass
 def UpdateBaml(self,target,updates):
  """
  UpdateBaml(self: BamlLocalizer,target: Stream,updates: BamlLocalizationDictionary)

   Applies resource updates to the BAML source and writes the updated version to a specified stream 

    in order to create a localized version of the source BAML.

  

  

   target: The stream that will receive the updated BAML.

   updates: The resource updates to be applied to the source BAML.
  """
  pass
 @staticmethod
 def __new__(self,source,resolver=None,comments=None):
  """
  __new__(cls: type,source: Stream)

  __new__(cls: type,source: Stream,resolver: BamlLocalizabilityResolver)

  __new__(cls: type,source: Stream,resolver: BamlLocalizabilityResolver,comments: TextReader)
  """
  pass
 ErrorNotify=None


class BamlLocalizerError(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies error conditions that may be encountered by the System.Windows.Markup.Localizer.BamlLocalizer.

 

 enum BamlLocalizerError,values: DuplicateElement (1),DuplicateUid (0),IncompleteElementPlaceholder (2),InvalidCommentingXml (3),InvalidLocalizationAttributes (4),InvalidLocalizationComments (5),InvalidUid (6),MismatchedElements (7),SubstitutionAsPlaintext (8),UidMissingOnChildElement (9),UnknownFormattingTag (10)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DuplicateElement=None
 DuplicateUid=None
 IncompleteElementPlaceholder=None
 InvalidCommentingXml=None
 InvalidLocalizationAttributes=None
 InvalidLocalizationComments=None
 InvalidUid=None
 MismatchedElements=None
 SubstitutionAsPlaintext=None
 UidMissingOnChildElement=None
 UnknownFormattingTag=None
 value__=None


class BamlLocalizerErrorNotifyEventArgs(EventArgs):
 """ Provides required event data for the System.Windows.Markup.Localizer.BamlLocalizer.ErrorNotify event. """
 Error=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the specific error condition encountered by System.Windows.Markup.Localizer.BamlLocalizer.



Get: Error(self: BamlLocalizerErrorNotifyEventArgs) -> BamlLocalizerError



"""

 Key=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the key associated with the resource that generated the error condition.



Get: Key(self: BamlLocalizerErrorNotifyEventArgs) -> BamlLocalizableResourceKey



"""



class BamlLocalizerErrorNotifyEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.Windows.Markup.Localizer.BamlLocalizer.ErrorNotify event.

 

 BamlLocalizerErrorNotifyEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: BamlLocalizerErrorNotifyEventHandler,sender: object,e: BamlLocalizerErrorNotifyEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: BamlLocalizerErrorNotifyEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: BamlLocalizerErrorNotifyEventHandler,sender: object,e: BamlLocalizerErrorNotifyEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class ElementLocalizability(object):
 """
 Represents localizability settings for an element in BAML.

 

 ElementLocalizability()

 ElementLocalizability(formattingTag: str,attribute: LocalizabilityAttribute)
 """
 @staticmethod
 def __new__(self,formattingTag=None,attribute=None):
  """
  __new__(cls: type)

  __new__(cls: type,formattingTag: str,attribute: LocalizabilityAttribute)
  """
  pass
 Attribute=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the associated element's localizability attribute.



Get: Attribute(self: ElementLocalizability) -> LocalizabilityAttribute



Set: Attribute(self: ElementLocalizability)=value

"""

 FormattingTag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the associated element's formatting tag.



Get: FormattingTag(self: ElementLocalizability) -> str



Set: FormattingTag(self: ElementLocalizability)=value

"""



